@@ -40,6 +40,7 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/sync_power_state_interval').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('compute/live_migration_wait_for_vif_plug').with_value('<SERVICE DEFAULT>') }
 
       it { is_expected.to_not contain_package('cryptsetup').with( :ensure => 'present' )}
 
@@ -55,6 +56,23 @@ describe 'nova::compute' do
         is_expected.to contain_nova_config('DEFAULT/internal_service_availability_zone').with_value('<SERVICE DEFAULT>')
       end
 
+      it 'configures vendordata' do
+        is_expected.to contain_nova_config('api/vendordata_jsonfile_path').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/vendordata_providers').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/vendordata_dynamic_targets').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/vendordata_dynamic_connect_timeout').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/vendordata_dynamic_read_timeout').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/vendordata_dynamic_failure_fatal').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/auth_type').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/auth_url').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/os_region_name').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/password').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/project_domain_name').with('value' => 'Default')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/project_name').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/user_domain_name').with('value' => 'Default')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/username').with('value' => '<SERVICE DEFAULT>')
+      end
+
       it { is_expected.to contain_nova_config('DEFAULT/heal_instance_info_cache_interval').with_value('60') }
 
       it 'installs genisoimage package and sets config_drive_format' do
@@ -89,6 +107,7 @@ describe 'nova::compute' do
           :sync_power_state_interval          => '0',
           :verify_glance_signatures           => true,
           :consecutive_build_service_disable_threshold => '9',
+          :live_migration_wait_for_vif_plug   => true,
         }
       end
 
@@ -122,7 +141,6 @@ describe 'nova::compute' do
       it 'configures vnc in nova.conf' do
         is_expected.to contain_nova_config('vnc/enabled').with_value(true)
         is_expected.to contain_nova_config('vnc/vncserver_proxyclient_address').with_value('127.0.0.1')
-        is_expected.to contain_nova_config('vnc/keymap').with_value('en-us')
         is_expected.to contain_nova_config('vnc/novncproxy_base_url').with_value(
           'http://127.0.0.1:6080/vnc_auto.html'
         )
@@ -153,6 +171,8 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value(true) }
       it { is_expected.to contain_nova_config('glance/verify_glance_signatures').with_value(true) }
 
+      it { is_expected.to contain_nova_config('compute/live_migration_wait_for_vif_plug').with_value(true) }
+
       it 'configures nova config_drive_format to vfat' do
         is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('vfat')
         is_expected.to_not contain_package('genisoimage').with(
@@ -187,18 +207,6 @@ describe 'nova::compute' do
       end
     end
 
-    context 'with barbican deprecated parameters' do
-      let :params do
-        {
-          :keymgr_api_class => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
-        }
-      end
-      it 'should set keymgr parameter' do
-        is_expected.to contain_nova_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
-        is_expected.to contain_package('cryptsetup').with( :ensure => 'present' )
-      end
-    end
-
     context 'when vcpu_pin_set and pci params are empty' do
       let :params do
         { :vcpu_pin_set    => ""}
@@ -219,21 +227,6 @@ describe 'nova::compute' do
       end
     end
 
-    context 'with neutron_enabled set to false' do
-      let :params do
-        { :neutron_enabled => false }
-      end
-
-      it 'installs bridge-utils package for nova-network' do
-        is_expected.to contain_package('bridge-utils').with(
-          :ensure => 'present',
-        )
-        is_expected.to contain_package('bridge-utils').that_requires('Anchor[nova::install::begin]')
-        is_expected.to contain_package('bridge-utils').that_comes_before('Anchor[nova::install::end]')
-      end
-
-    end
-
     context 'when neutron_physnets_numa_nodes_mapping and neutron_tunnel_numa_nodes are empty' do
       let :params do
         { :neutron_physnets_numa_nodes_mapping => {},
@@ -256,19 +249,6 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('neutron_tunnel/numa_nodes').with(:value => '1') }
     end
 
-    context 'with install_bridge_utils set to false' do
-      let :params do
-        { :install_bridge_utils => false }
-      end
-
-      it 'does not install bridge-utils package for nova-network' do
-        is_expected.to_not contain_package('bridge-utils').with(
-          :ensure => 'present',
-        )
-      end
-
-    end
-
     context 'with vnc_enabled set to false and spice_enabled set to true' do
       let :params do
         { :vnc_enabled => false,
@@ -278,7 +258,6 @@ describe 'nova::compute' do
       it 'disables vnc in nova.conf' do
         is_expected.to contain_nova_config('vnc/enabled').with_value(false)
         is_expected.to contain_nova_config('vnc/vncserver_proxyclient_address').with_ensure('absent')
-        is_expected.to contain_nova_config('vnc/keymap').with_ensure('absent')
         is_expected.to_not contain_nova_config('vnc/novncproxy_base_url')
       end
 
@@ -343,13 +322,6 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit_period').with_value('year') }
     end
 
-    context 'with vnc_keymap set to fr' do
-      let :params do
-        { :vnc_keymap => 'fr', }
-      end
-
-      it { is_expected.to contain_nova_config('vnc/keymap').with_value('fr') }
-    end
   end
 
   on_supported_os({
